@@ -78,6 +78,13 @@ ard_categorical_ci.data.frame <- function(data,
     cards::process_selectors(data, strata = {{ strata }})
     check_scalar(strata)
   }
+
+  # if the method is strat_wilson, `weights` and `strata` cannot contain NA values
+  if (method %in% c("strat_wilson")) {
+    if (any(is.na({{ weights }}))) {
+      cli::cli_warn("{.field weights} cannot contain {.val NA} values.")
+    }
+  }
   cards::process_formula_selectors(
     data[variables],
     value = value
