@@ -20,7 +20,7 @@ ard_missing.survey.design <- function(data,
                                           "N_obs_unweighted", "N_miss_unweighted", "N_nonmiss_unweighted",
                                           "p_miss_unweighted", "p_nonmiss_unweighted"
                                         ),
-                                      fmt_fn = NULL,
+                                      fmt_fun = NULL,
                                       stat_label =
                                         everything() ~ list(
                                           N_obs = "Total N",
@@ -34,11 +34,22 @@ ard_missing.survey.design <- function(data,
                                           p_miss_unweighted = "% Missing (unweighted)",
                                           p_nonmiss_unweighted = "% not Missing (unweighted)"
                                         ),
+                                      fmt_fn = deprecated(),
                                       ...) {
   set_cli_abort_call()
   check_dots_empty()
   check_pkg_installed(pkg = "survey")
 
+  # deprecated args ------------------------------------------------------------
+  if (lifecycle::is_present(fmt_fn)) {
+    lifecycle::deprecate_soft(
+      when = "0.2.5",
+      what = "ard_missing(fmt_fn)",
+      with = "ard_missing(fmt_fun)"
+    )
+    fmt_fun <- fmt_fn
+  }
+
   # process inputs -------------------------------------------------------------
   check_not_missing(variables)
   cards::process_selectors(
@@ -59,7 +70,7 @@ ard_missing.survey.design <- function(data,
   cards::process_formula_selectors(
     data$variables[variables],
     statistic = statistic,
-    fmt_fn = fmt_fn,
+    fmt_fun = fmt_fun,
     stat_label = stat_label
   )
   cards::fill_formula_selectors(
@@ -111,16 +122,16 @@ ard_missing.survey.design <- function(data,
           .data$stat_name %in% "p_unweighted" & .data$variable_level %in% TRUE ~ "p_nonmiss_unweighted"
         )
     ) |>
-    dplyr::select(-cards::all_ard_variables("levels"), -"stat_label", -"fmt_fn") |>
+    dplyr::select(-cards::all_ard_variables("levels"), -"stat_label", -"fmt_fun") |>
     dplyr::slice(1L, .by = c(cards::all_ard_groups(), cards::all_ard_variables(), "stat_name"))
 
-  # final processing of fmt_fn -------------------------------------------------
+  # final processing of fmt_fun ------------------------------------------------
   result <- result |>
     .process_nested_list_as_df(
-      arg = fmt_fn,
-      new_column = "fmt_fn"
+      arg = fmt_fun,
+      new_column = "fmt_fun"
     ) |>
-    .default_svy_cat_fmt_fn()
+    .default_svy_cat_fmt_fun()
 
   # merge in statistic labels --------------------------------------------------
   result <- result |>
