@@ -20,7 +20,7 @@
 #' @return ARD data frame
 #' @export
 #'
-#' @examplesIf do.call(asNamespace("cardx")$is_pkg_installed, list(pkg = c("survey", "broom"), reference_pkg = "cardx"))
+#' @examplesIf do.call(asNamespace("cardx")$is_pkg_installed, list(pkg = c("survey", "broom")))
 #' data(api, package = "survey")
 #' dclus1 <- survey::svydesign(id = ~dnum, weights = ~pw, data = apiclus1, fpc = ~fpc)
 #'
@@ -29,7 +29,7 @@ ard_survey_svychisq <- function(data, by, variables, statistic = "F", ...) {
   set_cli_abort_call()
 
   # check installed packages ---------------------------------------------------
-  check_pkg_installed(c("survey", "broom"), reference_pkg = "cardx")
+  check_pkg_installed(c("survey", "broom"))
 
   # check/process inputs -------------------------------------------------------
   check_not_missing(data)
