@@ -1,6 +1,7 @@
-skip_if_not(is_pkg_installed("survey", reference_pkg = "cardx"))
+skip_if_not(is_pkg_installed(c("survey", "withr")))
 
 test_that("ard_attributes.survey.design() works", {
+  withr::local_options(list(width = 120))
   data(api, package = "survey")
   dclus1 <- survey::svydesign(id = ~dnum, weights = ~pw, data = apiclus1, fpc = ~fpc)
 
